@@ -3,11 +3,46 @@
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-from notebook.notebookapp import NotebookApp
-from traitlets import Unicode
+
+from notebook.notebookapp import NotebookApp, flags
+from jupyter_core.application import JupyterApp
+
+from traitlets import Bool, Unicode
 
 from ._version import __version__
 from .extension import load_jupyter_server_extension
+from .commands import build, clean, describe
+
+
+class LabBuildApp(JupyterApp):
+    version = __version__
+    description = "Build the JupyterLab application"
+
+    def start(self):
+        build()
+
+
+class LabCleanApp(JupyterApp):
+    version = __version__
+    description = "Clean the JupyterLab application"
+
+    def start(self):
+        clean()
+
+
+class LabDescribeApp(JupyterApp):
+    version = __version__
+    description = "Git description the JupyterLab application"
+
+    def start(self):
+        print(describe())
+
+
+lab_flags = dict(flags)
+lab_flags['dev-mode'] = (
+    {'LabApp': {'dev_mode': True}},
+    "Start the app in dev mode."
+)
 
 
 class LabApp(NotebookApp):
@@ -25,11 +60,20 @@ class LabApp(NotebookApp):
         jupyter lab --certfile=mycert.pem # use SSL/TLS certificate
     """
 
-    subcommands = dict()
+    flags = lab_flags
+
+    subcommands = dict(
+        build=(LabBuildApp, LabBuildApp.description.splitlines()[0]),
+        clean=(LabCleanApp, LabCleanApp.description.splitlines()[0]),
+        describe=(LabDescribeApp, LabBuildApp.description.splitlines()[0])
+    )
 
     default_url = Unicode('/lab', config=True,
         help="The default URL to redirect to from `/`")
 
+    dev_mode = Bool(False, config=True,
+        help="Whether to start the app in dev mode")
+
     def init_server_extensions(self):
         """Load any extensions specified by config.
 
@@ -47,6 +91,7 @@ class LabApp(NotebookApp):
             self.log.warn(msg)
             load_jupyter_server_extension(self)
 
+
 #-----------------------------------------------------------------------------
 # Main entry point
 #-----------------------------------------------------------------------------
